@@ -4,19 +4,15 @@
 @date: 2022/4/3 下午1:37
 @file: build.py
 @author: zj
-@description: 
+@description: adjust_learning_rate and build_lr_scheduler
 """
 
 from yacs.config import CfgNode
 from torch.optim.optimizer import Optimizer
 
-from .multi_step_lr import build_multistep_lr
-from .cosine_annealing_lr import build_cosine_annearling_lr
+from . import multi_step_lr, cosine_annealing_lr
 
-__supported_lr_scheduler__ = [
-    'MultiStepLR',
-    'CosineAnnealingLR'
-]
+__all__ = ["adjust_learning_rate", "build_lr_scheduler"]
 
 
 def adjust_learning_rate(cfg: CfgNode, optimizer: Optimizer, epoch: int, step: int, len_epoch: int) -> None:
@@ -24,7 +20,7 @@ def adjust_learning_rate(cfg: CfgNode, optimizer: Optimizer, epoch: int, step: i
     lr = cfg.OPTIMIZER.LR
 
     warmup_epoch = cfg.LR_SCHEDULER.WARMUP_EPOCH
-    """Warmup"""
+    # Warmup
     if epoch < warmup_epoch + 1:
         lr = lr * float(1 + step + (epoch - 1) * len_epoch) / (warmup_epoch * len_epoch)
 
@@ -34,7 +30,6 @@ def adjust_learning_rate(cfg: CfgNode, optimizer: Optimizer, epoch: int, step: i
 
 def build_lr_scheduler(cfg: CfgNode, optimizer: Optimizer):
     lr_scheduler_name = cfg.LR_SCHEDULER.NAME
-    assert lr_scheduler_name in __supported_lr_scheduler__
 
     warmup = cfg.LR_SCHEDULER.IS_WARMUP
     warmup_epoch = cfg.LR_SCHEDULER.WARMUP_EPOCH
@@ -43,17 +38,19 @@ def build_lr_scheduler(cfg: CfgNode, optimizer: Optimizer):
     if warmup:
         max_epoch = max_epoch - warmup_epoch
 
-    if lr_scheduler_name == 'MultiStepLR':
+    if lr_scheduler_name in multi_step_lr.__all__:
         milestones = cfg.LR_SCHEDULER.MULTISTEP_LR.MILESTONES
         gamma = cfg.LR_SCHEDULER.MULTISTEP_LR.GAMMA
         step_size = cfg.LR_SCHEDULER.MULTISTEP_LR.STEP_SIZE
         if step_size != 0:
             milestones = list(range(0, max_epoch, step_size))
 
-        return build_multistep_lr(optimizer, milestones=milestones, gamma=gamma)
-    elif lr_scheduler_name == 'CosineAnnealingLR':
-        return build_cosine_annearling_lr(optimizer,
-                                          max_epoch=max_epoch,
-                                          minimal_lr=1e-6)
+        lr_scheduler = multi_step_lr.__dict__[lr_scheduler_name](optimizer, milestones=milestones, gamma=gamma)
+    elif lr_scheduler_name in cosine_annealing_lr.__all__:
+        lr_scheduler = cosine_annealing_lr.__dict__[lr_scheduler_name](optimizer,
+                                                                       max_epoch=max_epoch,
+                                                                       minimal_lr=1e-6)
     else:
         raise ValueError(f"{lr_scheduler_name} does not support")
+
+    return lr_scheduler
